==> rest-sdk-connector-model-0.3.0-sources.jar: com/mulesoft/connectivity/rest/sdk/internal/connectormodel/builder/TriggerParameterBuilder.java <==
/*
 * (c) 2003-2021 MuleSoft, Inc. This software is protected under international copyright
 * law. All use of this software is subject to MuleSoft's Master Subscription Agreement
 * (or other master license agreement) separately entered into in writing between you and
 * MuleSoft. If such an agreement is not in place, you may not use the software.
 */
package com.mulesoft.connectivity.rest.sdk.internal.connectormodel.builder;

import static java.util.Objects.requireNonNull;
import static org.apache.commons.lang3.ObjectUtils.defaultIfNull;

import com.mulesoft.connectivity.rest.sdk.internal.connectormodel.generic.ParameterDataType;
import com.mulesoft.connectivity.rest.sdk.internal.connectormodel.trigger.TriggerParameter;

public class TriggerParameterBuilder {

  private final String name;
  private String displayName;
  private ParameterDataType dataType;
  private String description;
  private Boolean required;

  public TriggerParameterBuilder(String name) {
    requireNonNull(name);
    this.name = name;
  }

  public String getName() {
    return name;
  }

  public TriggerParameterBuilder displayName(String displayName) {
    this.displayName = defaultIfNull(displayName, this.displayName);
    return this;
  }

  public TriggerParameterBuilder dataType(ParameterDataType dataType) {
    this.dataType = defaultIfNull(dataType, this.dataType);
    return this;
  }

  public TriggerParameterBuilder description(String description) {
    this.description = defaultIfNull(description, this.description);
    return this;
  }

  public TriggerParameterBuilder required(Boolean required) {
    this.required = defaultIfNull(required, this.required);
    return this;
  }

  TriggerParameter build() {
    return new TriggerParameter(name, displayName, dataType, description, required);
  }
}

==> rest-sdk-connector-model-0.4.0-sources.jar: com/mulesoft/connectivity/rest/sdk/internal/connectormodel/builder/TriggerParameterBuilder.java <==
/*
 * (c) 2003-2021 MuleSoft, Inc. This software is protected under international copyright
 * law. All use of this software is subject to MuleSoft's Master Subscription Agreement
 * (or other master license agreement) separately entered into in writing between you and
 * MuleSoft. If such an agreement is not in place, you may not use the software.
 */
package com.mulesoft.connectivity.rest.sdk.internal.connectormodel.builder;

import static java.util.Objects.requireNonNull;
import static org.apache.commons.lang3.ObjectUtils.defaultIfNull;

import com.mulesoft.connectivity.rest.sdk.internal.connectormodel.TypeSchemaPool;
import com.mulesoft.connectivity.rest.sdk.internal.connectormodel.generic.ParameterDataType;
import com.mulesoft.connectivity.rest.sdk.internal.connectormodel.trigger.TriggerParameter;
import com.mulesoft.connectivity.rest.sdk.internal.connectormodel.type.TypeDefinition;

import java.util.List;

public class TriggerParameterBuilder {

  private final String name;
  private String displayName;
  private ParameterDataType dataType;
  private final TypeDefinitionBuilder typeDefinitionBuilder = new TypeDefinitionBuilder();
  private String description;
  private Boolean required;

  public TriggerParameterBuilder(String name) {
    requireNonNull(name);
    this.name = name;
  }

  public String getName() {
    return name;
  }

  public TriggerParameterBuilder displayName(String displayName) {
    this.displayName = defaultIfNull(displayName, this.displayName);
    return this;
  }

  public TriggerParameterBuilder dataType(ParameterDataType dataType) {
    this.dataType = defaultIfNull(dataType, this.dataType);
    return this;
  }

  public TriggerParameterBuilder description(String description) {
    this.description = defaultIfNull(description, this.description);
    return this;
  }

  public TriggerParameterBuilder required(Boolean required) {
    this.required = defaultIfNull(required, this.required);
    return this;
  }

  public TypeDefinitionBuilder getTypeDefinitionBuilder() {
    return this.typeDefinitionBuilder;
  }

  public TriggerParameter build() {
    return new TriggerParameter(name, displayName, dataType, null, description, required);
  }

  public TriggerParameter build(TypeSchemaPool typeSchemaPool, List<String> collisionParameterNames) {
    TypeDefinition typeDefinition = null;
    if (dataType == null) {
      typeDefinition = getTypeDefinitionBuilder().build(typeSchemaPool, null);
    }
    final TriggerParameter triggerParameter =
        new TriggerParameter(name, displayName, dataType, typeDefinition, description, required);
    collisionParameterNames.add(triggerParameter.getInternalName());
    return triggerParameter;
  }
}
